@@ -109,13 +109,25 @@ AO Flat Star:
 
         for oc in sciences:
             sct = oc.SCTarget
+            extrainfos = self.get(sct, "EXTRA_INFORMATIONS")
             ftt = self.get(oc, "FTTarget")
             aot = self.get(oc, "AOTarget")
+
             buffer += oc.observationConstraints.LSTinterval + "\n"
             buffer += "Object:\n"
             fluxes = ", ".join([e[0] + "=" + e[1]
                                 for e in ob.getFluxes(sct).items()])
-            info = sct.SPECTYP + ", " + sct.PARALLAX
+            try:
+                info = sct.SPECTYP
+            except:
+                info = "no SPECTYP"
+            info+=", "
+            try:
+                info += sct.PARALLAX
+            except:
+                info += "no PARALLAX"
+
+
             buffer += sct.name + " (" + info + ") : " + fluxes + "\n"
             if ftt:
                 buffer += "Fringe Finder:\n"
@@ -133,6 +145,12 @@ AO Flat Star:
                 for cal in cals:
                     buffer += "- " + cal + "\n"
 
+            # Display Extra_Informations if any
+            if extrainfos:
+                buffer += "Extra_infos:\n"
+                for field in extrainfos._fields:
+                    buffer += "- " + field + "=" + getattr(extrainfos,field) +"\n"
+
             buffer += _HR
 
         return buffer
