@@ -97,7 +97,7 @@ class Gravity(VltiInstrument):
             # Retrieve Fluxes
             acqTSF.COU_GS_MAG = self.getFlux(scienceTarget, "V")
             acqTSF.SEQ_INS_SOBJ_MAG = self.getFlux(scienceTarget, "K")
-            if ob.getPeriod() == 110: # P111 use back again FI_HMAG
+            if ob.getPeriod() >= 110: # P111 use back again FI_HMAG
                 acqTSF.SEQ_INS_SOBJ_HMAG = self.getFlux(scienceTarget, "H")
             else:
                 acqTSF.SEQ_FI_HMAG = self.getFlux(scienceTarget, "H")
